@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 import os
 import shutil
 import tempfile
@@ -262,3 +263,6 @@ class LargeObjectTests(unittest.TestCase):
 
 def test_suite():
     return unittest.TestLoader().loadTestsFromName(__name__)
+
+if __name__ == "__main__":
+    unittest.main()
\ No newline at end of file
