@@ -1,17 +1,26 @@
 #!/usr/bin/env python
+#
 # types_basic.py - tests for basic types conversions
 #
-# Copyright (C) 2004 Federico Di Gregorio  <fog@debian.org>
+# Copyright (C) 2004-2010 Federico Di Gregorio  <fog@debian.org>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by the
-# Free Software Foundation; either version 2, or (at your option) any later
-# version.
+# psycopg2 is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Lesser General Public License as published
+# by the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTIBILITY
-# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-# for more details.
+# In addition, as a special exception, the copyright holders give
+# permission to link this program with the OpenSSL library (or with
+# modified versions of OpenSSL that use the same license as OpenSSL),
+# and distribute linked combinations including the two.
+#
+# You must obey the GNU Lesser General Public License in all respects for
+# all of the code used other than OpenSSL.
+#
+# psycopg2 is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+# License for more details.
 
 try:
     import decimal
@@ -50,15 +59,25 @@ class TypesBasicTests(unittest.TestCase):
         self.failUnless(s == 1971, "wrong integer quoting: " + str(s))
         s = self.execute("SELECT %s AS foo", (1971L,))
         self.failUnless(s == 1971L, "wrong integer quoting: " + str(s))
-        # Python 2.4 defaults to Decimal?
-        if sys.version_info[0] >= 2 and sys.version_info[1] >= 4:
-            s = self.execute("SELECT %s AS foo", (19.10,))
-            self.failUnless(s - decimal.Decimal("19.10") == 0,
-                            "wrong decimal quoting: " + str(s))
-        else:
+        if sys.version_info[0] < 2 or sys.version_info[1] < 4:
             s = self.execute("SELECT %s AS foo", (19.10,))
             self.failUnless(abs(s - 19.10) < 0.001,
-                            "wrong float quoting: " + str(s))
+                        "wrong float quoting: " + str(s))
+
+    def testDecimal(self):
+        if sys.version_info[0] >= 2 and sys.version_info[1] >= 4:
+            s = self.execute("SELECT %s AS foo", (decimal.Decimal("19.10"),))
+            self.failUnless(s - decimal.Decimal("19.10") == 0,
+                            "wrong decimal quoting: " + str(s))
+            s = self.execute("SELECT %s AS foo", (decimal.Decimal("NaN"),))
+            self.failUnless(str(s) == "NaN", "wrong decimal quoting: " + str(s))
+            self.failUnless(type(s) == decimal.Decimal, "wrong decimal conversion: " + repr(s))
+            s = self.execute("SELECT %s AS foo", (decimal.Decimal("infinity"),))
+            self.failUnless(str(s) == "NaN", "wrong decimal quoting: " + str(s))
+            self.failUnless(type(s) == decimal.Decimal, "wrong decimal conversion: " + repr(s))
+            s = self.execute("SELECT %s AS foo", (decimal.Decimal("-infinity"),))
+            self.failUnless(str(s) == "NaN", "wrong decimal quoting: " + str(s))
+            self.failUnless(type(s) == decimal.Decimal, "wrong decimal conversion: " + repr(s))
 
     def testFloat(self):
         s = self.execute("SELECT %s AS foo", (float("nan"),))
